summaryrefslogtreecommitdiff
path: root/src/date.c
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1995-11-27 05:34:31 +0000
committerJim Meyering <jim@meyering.net>1995-11-27 05:34:31 +0000
commit57ec0f45c90bde207866d65aa7752d56cd55ac04 (patch)
tree5e7ed870725ad3f21baf9fc96bac635fe8b10d85 /src/date.c
parenta7830ac93b955ac0be4a15d65a3e5a67f1635b8b (diff)
downloadcoreutils-57ec0f45c90bde207866d65aa7752d56cd55ac04.tar.xz
s/non-zero/nonzero/g
Diffstat (limited to 'src/date.c')
-rw-r--r--src/date.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/date.c b/src/date.c
index 49ca9ef75..378b30262 100644
--- a/src/date.c
+++ b/src/date.c
@@ -50,13 +50,13 @@ static void usage ();
/* The name this program was run with, for error messages. */
char *program_name;
/* If non-zero, display usage information and exit. */
static int show_help;
/* If non-zero, print the version on standard output and exit. */
static int show_version;
/* If non-zero, print or set Coordinated Universal Time. */
static int universal_time = 0;
static struct option const long_options[] =
@@ -76,7 +76,7 @@ static struct option const long_options[] =
/* Parse each line in INPUT_FILENAME as with --date and display the
each resulting time and date. If the file cannot be opened, tell why
then exit. Issue a diagnostic for any lines that cannot be parsed.
- If any line cannot be parsed, return non-zero; otherwise return zero. */
+ If any line cannot be parsed, return nonzero; otherwise return zero. */
static int
batch_convert (input_filename, format)
@@ -50,13 +50,13 @@ static void usage ();
/* The name this program was run with, for error messages. */
char *program_name;
-/* If non-zero, display usage information and exit. */
+/* If nonzero, display usage information and exit. */
static int show_help;
@@ -50,13 +50,13 @@ static void usage ();
static int show_help;
-/* If non-zero, print the version on standard output and exit. */
+/* If nonzero, print the version on standard output and exit. */
static int show_version;
@@ -50,13 +50,13 @@ static void usage ();
static int show_version;
-/* If non-zero, print or set Coordinated Universal Time. */
+/* If nonzero, print or set Coordinated Universal Time. */
static int universal_time = 0;
static struct option const long_options[] =